#
# spec file for package libindicator
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libindicator3
%define soname_gtk2 libindicator
%define sover   7
%define _version 16.10.0+18.04.20171205.1
Name:           libindicator
Version:        16.10.0+bzr20171205
Release:        150200.3.2.1
Summary:        Panel indicator applet libraries
License:        GPL-3.0-only
Group:          System/GUI/Other
URL:            https://launchpad.net/libindicator
Source:         https://launchpad.net/ubuntu/+archive/primary/+files/%{name}_%{_version}.orig.tar.gz
# PATCH-FIX-OPENSUSE libindicator-disable-werror.patch hrvoje.senjan@gmail.com -- Disable -Werror.
Patch0:         libindicator-disable-werror.patch
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libido3-0.1)
BuildRequires:  pkgconfig(systemd)

%description
This library contains information to build indicators to go into
the indicator applet.

%package -n %{soname}-%{sover}
Summary:        Panel indicator applet library
Group:          System/Libraries

%description -n %{soname}-%{sover}
This package provides the libraries required to build indicators
and to go into the indicator applet.

%package -n %{soname_gtk2}%{sover}
Summary:        Panel indicator applet library for GTK+2
Group:          System/Libraries

%description -n %{soname_gtk2}%{sover}
This package provides the libraries required to build indicators
and to go into the indicator applet.

%package -n %{soname}-devel
Summary:        Development files for the Panel indicator applet
Group:          Development/Libraries/Other
Requires:       %{soname}-%{sover} = %{version}

%description -n %{soname}-devel
This package provides the development files required to build
indicators and to go into the indicator applet.

%package -n %{soname_gtk2}-devel
Summary:        Development files for the Panel indicator applet (GTK+2 variant)
Group:          Development/Libraries/Other
Requires:       %{soname_gtk2}%{sover} = %{version}

%description -n %{soname_gtk2}-devel
This package provides the development files required to build
indicators and to go into the indicator applet.

%package -n indicator-common
Summary:        Indicator shared files
Group:          System/Libraries

%description -n indicator-common
A package that has files needed to work with the indicators. This
includes the systemd indicators-pre.target.

%prep
%setup -q -c
%patch0 -p1

%build
export CFLAGS="%{optflags} -Wno-error"
%global _configure ../configure
NOCONFIGURE=1 gnome-autogen.sh
for ver in 2 3; do
    mkdir build-gtk$ver
    pushd build-gtk$ver
    %configure --disable-static --with-gtk=$ver
    make %{?_smp_mflags} V=1
    popd
done

%install
for ver in 2 3; do
    pushd build-gtk$ver
    %make_install
    popd
done
find %{buildroot} -type f -name "*.la" -delete -print

# This dummy indicator is fairly useless, it is not shipped in Ubuntu.
rm %{buildroot}%{_libdir}/libdummy-indicator*.so

%post -n %{soname}-%{sover} -p /sbin/ldconfig

%postun -n %{soname}-%{sover} -p /sbin/ldconfig

%post -n %{soname_gtk2}%{sover} -p /sbin/ldconfig

%postun -n %{soname_gtk2}%{sover} -p /sbin/ldconfig

%files -n %{soname}-%{sover}
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{soname_gtk2}%{sover}
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS
%{_libdir}/%{soname_gtk2}.so.%{sover}*

%files -n %{soname}-devel
%{_includedir}/%{soname}-0.4/
%{_libexecdir}/indicator-loader3
%{_libdir}/%{soname}.so
%{_datadir}/%{name}/
%{_libdir}/pkgconfig/indicator3-0.4.pc

%files -n %{soname_gtk2}-devel
%{_includedir}/%{soname_gtk2}-0.4/
%{_libdir}/%{soname_gtk2}.so
%{_libdir}/pkgconfig/indicator-0.4.pc

%files -n indicator-common
%{_prefix}/lib/systemd/user/indicators-pre.target

%changelog
* Fri Mar 20 2020 yfjiang@suse.com
- A shared systemd target for user session is shipped with the
  source, pack it up properly.
  https://bazaar.launchpad.net/~indicator-applet-developers/libindicator/trunk.16.10/revision/534
* Wed Oct 16 2019 dimstar@opensuse.org
- Inject -Wno-error into CFLAGS. It's kinda ridiculous for code
  that is not maintained upstream to pass -Werror by default and
  then not catching up. So for now we accept warnings.
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Replace dont-build-debug-tools.patch with
  libindicator-disable-werror.patch: no need to avoid Ido.
* Sat Mar 10 2018 dimstar@opensuse.org
- Update to version 16.10.0+bzr20171205:
  + Fix build with GNOME 3.28.
- Rebase dont-build-debug-tools.patch.
- Add pkgconfig(libido3-0.1) BuildRequires: new dependency.
* Sat Dec 26 2015 sor.alexei@meowr.ru
- Update to 12.10.2+bzr20140922:
  * Add -lm via LDADD to resolve FTBFS in Ubuntu 16.04.
- Remove fix-compilation.patch: fixed upstream.
* Sun Oct 18 2015 sor.alexei@meowr.ru
- fix-compilation.patch: fix "cannot find -lglib-2.0-lm"
  compilation error.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 12.10.2+bzr20140922:
  + No changes.
- Spec cleanup.
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 12.10.2+14.04.20141007.1
  + No changelog available
- Use download Url as source
* Fri Mar  7 2014 hrvoje.senjan@gmail.com
- Update to 12.10.2+14.04.20140304
  * Latest release available in Ubuntu archives - no changelog provided
- Enable build of GTK-3.0 subpackage
- Added dont-build-debug-tools.patch, tools are used only for tests
  & developing indicators. Also, it pulls libido requirement, which
  does not exists on openSUSE
* Fri Sep 20 2013 johann.luce@wanadoo.fr
- Fix System/Libraries group for lib
* Wed Feb 27 2013 p.drouand@gmail.com
- Initial release
